==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/util/ssh/SSHException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SSHException.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2008 - 2010 Ifremer, Code Lutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util.ssh;

/**
 * SSHException.
 *
 * @author chatellier
 * @version $Revision: 3124 $
 * 
 * Last update : $Date: 2010-11-29 19:14:09 +0100 (Mon, 29 Nov 2010) $
 * By : $Author: chatellier $
 */
public class SSHException extends Exception {

    /** serialVersionUID. */
    private static final long serialVersionUID = -198651402309210758L;

    /**
     * Constructs a new exception with the specified detail message.
     * 
     * @param message message
     * @param cause cause
     */
    public SSHException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * 
     * @param message message
     */
    public SSHException(String message) {
        super(message);
    }

    /**
     * Constructs a new exception with the specified cause and a detail message
     * of (cause==null ? null : cause.toString()) (which typically contains the
     * class and detail message of cause).
     * 
     * @param cause cause
     */
    public SSHException(Throwable cause) {
        super(cause);
    }

}

==> isis-fish-4.3.0.2-20140616.104318-1-sources.jar: fr/ifremer/isisfish/util/ssh/SSHException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SSHException.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2008 - 2010 Ifremer, Code Lutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util.ssh;

/**
 * SSHException.
 *
 * @author chatellier
 * @version $Revision: 3798 $
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (mar. 30 oct. 2012) $
 * By : $Author: echatellier $
 */
public class SSHException extends Exception {

    /** serialVersionUID. */
    private static final long serialVersionUID = -198651402309210758L;

    /**
     * Constructs a new exception with the specified detail message.
     * 
     * @param message message
     * @param cause cause
     */
    public SSHException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * 
     * @param message message
     */
    public SSHException(String message) {
        super(message);
    }

    /**
     * Constructs a new exception with the specified cause and a detail message
     * of (cause==null ? null : cause.toString()) (which typically contains the
     * class and detail message of cause).
     * 
     * @param cause cause
     */
    public SSHException(Throwable cause) {
        super(cause);
    }

}
